@@ -14,6 +14,7 @@ from pymtl3.passes.testcases import (
     CaseBits32ConnectSubCompAttrComp,
 )
 
+from ..StructuralRTLIRGenL2Pass import StructuralRTLIRGenL2Pass
 from .StructuralRTLIRGenL1Pass_test import gen_connections
 
 
@@ -21,19 +22,19 @@ def test_L4_subcomp_attr():
   a = CaseBits32ConnectSubCompAttrComp.DUT()
   a.elaborate()
   a.apply( StructuralRTLIRGenL4Pass( gen_connections( a ) ) )
-  ns = a._pass_structural_rtlir_gen
+  connections = a.get_metadata( StructuralRTLIRGenL2Pass.connections )
   comp = CurComp(a, 's')
   # The first two signals are clk and reset
-  assert ns.connections[2] == \
+  assert connections[2] == \
     (SubCompAttr(CurCompAttr(comp, 'b'), 'out'), CurCompAttr(comp, 'out'))
 
 def test_L4_subcomp_index():
   a = CaseBits32ArrayConnectSubCompAttrComp.DUT()
   a.elaborate()
   a.apply( StructuralRTLIRGenL4Pass( gen_connections( a ) ) )
-  ns = a._pass_structural_rtlir_gen
+  connections = a.get_metadata( StructuralRTLIRGenL2Pass.connections )
   comp = CurComp(a, 's')
   # The first ten signals are clks and resets
-  assert ns.connections[10] == \
+  assert connections[10] == \
     (SubCompAttr(ComponentIndex(CurCompAttr(comp, 'b'), 1), 'out'),
       CurCompAttr(comp, 'out'))
