@@ -10,8 +10,8 @@ from pymtl3.dsl import *
 from pymtl3.dsl.errors import UpblkCyclicError
 
 from ..GenDAGPass import GenDAGPass
+from ..PrepareSimPass import PrepareSimPass
 from ..SimpleSchedulePass import SimpleSchedulePass
-from ..SimpleTickPass import SimpleTickPass
 
 
 def _test_model( cls ):
@@ -19,14 +19,14 @@ def _test_model( cls ):
   A.elaborate()
   A.apply( GenDAGPass() )
   A.apply( SimpleSchedulePass() )
-  A.apply( SimpleTickPass() )
-  A.lock_in_simulation()
-  A.eval_combinational()
+  A.apply( PrepareSimPass() )
+
+  A.sim_reset()
+  A.sim_eval_combinational()
 
   T = 0
   while T < 5:
-    A.tick()
-    print(A.line_trace())
+    A.sim_tick()
     T += 1
   return A
 
@@ -51,36 +51,36 @@ def _test_false_cyclic_dependency():
       s.i = Wire(int)
       s.j = Wire(int)
 
-      @s.update
+      @update
       def up1():
         s.a = 10 + s.i
         s.b = s.d + 1
 
-      @s.update
+      @update
       def up2():
         s.c = s.a + 1
         s.e = s.d + 1
 
-      @s.update
+      @update
       def up3():
         s.d = s.c + 1
         print("up3 prints out d =", s.d)
 
-      @s.update
+      @update
       def up4():
         s.f = s.d + 1
 
-      @s.update
+      @update
       def up5():
         s.g = s.c + 1
         s.h = s.j + 1
         print("up5 prints out h =", s.h)
 
-      @s.update
+      @update
       def up6():
         s.i = s.i + 1
 
-      @s.update
+      @update
       def up7():
         s.j = s.g + 1
 
@@ -108,15 +108,15 @@ def _test_combinational_loop():
       s.c = Wire(int)
       s.d = Wire(int)
 
-      @s.update
+      @update
       def up1():
         s.b = s.d + 1
 
-      @s.update
+      @update
       def up2():
         s.c = s.b + 1
 
-      @s.update
+      @update
       def up3():
         s.d = s.c + 1
         print("up3 prints out d =", s.d)
@@ -139,12 +139,12 @@ def test_very_deep_dag():
 
   class Inner(Component):
     def construct( s ):
-      s.in_ = InPort(int)
-      s.out = OutPort(int)
+      s.in_ = InPort(32)
+      s.out = OutPort(32)
 
-      @s.update
+      @update
       def up():
-        s.out = s.in_ + 1
+        s.out @= s.in_ + 1
 
     def done( s ):
       return True
@@ -173,11 +173,11 @@ def test_sequential_break_loop():
       s.b = Wire( Bits32 )
       s.c = Wire( Bits32 )
 
-      @s.update
+      @update
       def up1():
-        s.b = s.c + 1
+        s.b @= s.c + 1
 
-      @s.update_ff
+      @update_ff
       def up2():
         if s.reset:
           s.c <<= 0
@@ -203,16 +203,15 @@ def test_connect_slice_int():
       s.x = Wire( Bits32 )
 
       s.y //= s.x[0:8]
-      @s.update
+      @update
       def sx():
-        s.x = 10 # Except
+        s.x @= 10
 
-  try:
-    _test_model( Top )
-  except TypeError as e:
-    assert str(e).startswith( "'int' object is not subscriptable" )
-    return
-  raise Exception("Should've thrown TypeError: 'int' object is not subscriptable")
+    def line_trace( s ):
+      return f"{s.x}"
+
+  # with @=, we don't have the subscript exception anymore
+  _test_model( Top )
 
 def test_const_connect_nested_struct_signal_to_struct():
 
@@ -235,7 +234,30 @@ def test_const_connect_nested_struct_signal_to_struct():
   x.elaborate()
   x.apply( GenDAGPass() )
   x.apply( SimpleSchedulePass() )
-  x.apply( SimpleTickPass() )
-  x.lock_in_simulation()
-  x.tick()
+  x.apply( PrepareSimPass() )
+
+  x.sim_reset()
+  x.sim_eval_combinational()
+  x.sim_tick()
   assert x.out == SomeMsg2(SomeMsg1(1,2),3)
+
+def test_equal_top_level():
+  class A(Component):
+    def construct( s ):
+      @update
+      def up():
+        print(1)
+
+  a = A()
+  a.apply( GenDAGPass() )
+  a.apply( SimpleSchedulePass() )
+  a.apply( PrepareSimPass() )
+  a.sim_reset()
+
+  try:
+    a.reset = 0
+    a.sim_tick()
+  except AssertionError as e:
+    print(e)
+    assert str(e).startswith("Please use @= to assign top level InPort")
+    return
